import { marked } from 'marked';

export function stripMarkdown(text: string): string {
	// Remove common markdown syntax
	return text
		.replace(/[*_~`#]+/g, '') // Remove formatting characters
		.replace(/\[([^\]]+)\]\([^)]+\)/g, '$1') // Replace links with just their text
		.replace(/!\[[^\]]*\]\([^)]+\)/g, '') // Remove images
		.replace(/^>+\s*/gm, '') // Remove blockquotes
		.replace(/^[-+*]\s+/gm, '') // Remove list markers
		.replace(/^\d+\.\s+/gm, '') // Remove numbered list markers
		.replace(/^#{1,6}\s+/gm, '') // Remove heading markers
		.replace(/\n{2,}/g, '\n') // Normalize multiple newlines
		.trim();
}

export async function renderMarkdown(
	text: string,
	linksTo: { id: string; title: string }[] = []
): Promise<string> {
	// Replace [[link]] with anchor tags using the backend-provided links
	const linkedText = text.replace(/\[\[([^\]]+)\]\]/g, (match, title) => {
		const link = linksTo.find((l) => l.title === title);
		if (link) {
			return `<a href="/notes/${link.id}" class="note-link">${title}</a>`;
		}
		return `<a href="/notes/new?title=${encodeURIComponent(title)}" class="note-link">${title}</a>`;
	});
	return marked(linkedText);
}
